from flask import Flask, request, jsonify, render_template_string
import ai_search_api.ai_search as ai

app = Flask(__name__)

def search(text):
    ai.req = text
    ai.run()
    results = ai.result
    result_two = results
    results = []
    return result_two

@app.route('/')
def home():
    return render_template_string(HTML_TEMPLATE)

@app.route('/start')
def start():
    return render_template_string(HTML_START_TEMPLATE)

@app.route('/start/update')
def update():
    import ai_search_api.update
    import ai_search_api.database as db
    return "Ai-search successful update! <a href='http://127.0.0.1:5000/start'>go to chat</a><br>to update the software write this command in the terminal of this folder: <code style='background: black; color: white; padding: 10px; border-radius: 10px;'>python update.py</code><br>Make sure you have deleted the temp repo folder before upgrading<hr>database content: <br>" + str(db.search) + "<hr><br><h3><a href='https://https://www.gitlab.com/neopad/'>@Neopad</a><br><hr><p>Thanks for your support!</p>"

@app.route('/api/search', methods=['POST'])
def api_search():
    text = request.json.get('text', '')
    result = search(text)
    return jsonify({'result': result})


HTML_TEMPLATE = """
<!DOCTYPE html>
<html lang="it">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ai-search - NeopadAI</title>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/gsap/3.11.4/gsap.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/gsap/3.11.4/ScrollTrigger.min.js"></script>
    <style>
        :root {
            --primary-color: #3e95e0;
            --background-color: #202123;
            --secondary-background: #343541;
            --text-color: #ececf1;
            --secondary-text-color: #c5c5d2;
            --accent-color: #10a37f;
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, Helvetica, Arial, sans-serif;
            line-height: 1.5;
            color: var(--text-color);
            background-color: var(--background-color);
            overflow-x: hidden;
        }

        .container {
            width: 100%;
            max-width: 1200px;
            margin: auto;
            padding: 0 20px;
        }

        header {
            background: rgba(32, 33, 35, 0.8);
            backdrop-filter: blur(20px);
            position: fixed;
            top: 0;
            left: 0;
            right: 0;
            z-index: 1000;
            transition: all 0.3s ease;
        }

        header .container {
            display: flex;
            justify-content: space-between;
            align-items: center;
            height: 60px;
        }

        header a {
            color: var(--text-color);
            text-decoration: none;
            font-weight: 400;
            font-size: 16px;
            transition: color 0.3s ease;
        }

        header nav a {
            margin-left: 30px;
            position: relative;
        }

        header nav a::after {
            content: '';
            position: absolute;
            width: 100%;
            height: 2px;
            bottom: -5px;
            left: 0;
            background-color: var(--primary-color);
            visibility: hidden;
            transform: scaleX(0);
            transition: all 0.3s ease-in-out;
        }

        header nav a:hover::after {
            visibility: visible;
            transform: scaleX(1);
        }

        header #branding {
            font-size: 24px;
            font-weight: 600;
            color: var(--primary-color);
        }

        #showcase {
            height: 100vh;
            display: flex;
            align-items: center;
            justify-content: center;
            text-align: center;
            background: var(--secondary-background);
            position: relative;
            overflow: hidden;
        }

        #showcase .content {
            max-width: 800px;
            position: relative;
            z-index: 1;
        }

        #showcase h1 {
            font-size: 48px;
            font-weight: 700;
            margin-bottom: 20px;
            color: var(--primary-color);
        }

        #showcase p {
            font-size: 20px;
            color: var(--secondary-text-color);
            margin-bottom: 30px;
        }

        .btn {
            display: inline-block;
            background-color: var(--primary-color);
            color: var(--text-color);
            padding: 12px 30px;
            border-radius: 4px;
            text-decoration: none;
            font-weight: 500;
            border: none;
            cursor: pointer;
            font-size: 16px;
        }

        .btn:hover {
            background-color: #3078b8;
        }

        #features {
            padding: 100px 0;
            background-color: var(--background-color);
        }

        .feature-grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
            gap: 40px;
        }

        .feature {
            background-color: var(--secondary-background);
            border-radius: 8px;
            padding: 30px;
            transition: all 0.3s ease;
        }

        .feature:hover {
            transform: translateY(-5px);
            box-shadow: 0 10px 20px rgba(0, 0, 0, 0.1);
        }

        .feature img {
            width: 60px;
            height: 60px;
            margin-bottom: 20px;
        }

        .feature h3 {
            margin-bottom: 15px;
            font-weight: 600;
            font-size: 20px;
            color: var(--primary-color);
        }

        .feature p {
            color: var(--secondary-text-color);
            font-size: 16px;
        }

        #demo {
            padding: 100px 0;
            background-color: var(--secondary-background);
        }

        #demo h2 {
            text-align: center;
            font-size: 32px;
            margin-bottom: 40px;
            color: var(--primary-color);
        }

        .demo-window {
            background-color: var(--background-color);
            border-radius: 8px;
            overflow: hidden;
            box-shadow: 0 10px 20px rgba(0,0,0,0.1);
        }

        .demo-toolbar {
            background-color: #2d2d30;
            padding: 10px;
            display: flex;
            justify-content: flex-start;
        }

        .demo-button {
            width: 12px;
            height: 12px;
            border-radius: 50%;
            margin-right: 8px;
        }

        .demo-button.red { background-color: #ff5f56; }
        .demo-button.yellow { background-color: #ffbd2e; }
        .demo-button.green { background-color: #27c93f; }

        .demo-content {
            padding: 20px;
            color: var(--text-color);
            font-family: 'Courier New', Courier, monospace;
            font-size: 14px;
            line-height: 1.5;
        }

        footer {
            background-color: var(--background-color);
            color: var(--secondary-text-color);
            text-align: center;
            padding: 40px 0;
            font-size: 14px;
        }

        footer .social-links {
            margin-top: 20px;
        }

        footer .social-links a {
            color: var(--secondary-text-color);
            margin: 0 10px;
            font-size: 20px;
            transition: color 0.3s ease;
        }

        footer .social-links a:hover {
            color: var(--primary-color);
        }

        @media (max-width: 768px) {
            header nav {
                display: none;
            }

            #showcase h1 {
                font-size: 36px;
            }

            #showcase p {
                font-size: 18px;
            }

            .feature-grid {
                grid-template-columns: 1fr;
            }
        }
    </style>
</head>
<body>
    <header>
        <div class="container">
            <div id="branding">NeopadAI</div>
        </div>
    </header>

    <section id="showcase">
        <div class="content">
            <h1>Test the new ai-search</h1>
            <p>Discover a new way to search. Efficient. Intuitive. Revolutionary.</p>
            <a href="/start" class="btn">Start Now</a>
            <a href="/start/update" class="btn">Update Now</a>
        </div>
    </section>

    <section id="demo">
        <div class="container">
            <h2>See NeopadAI in action</h2>
            <div class="demo-window">
                <div class="demo-toolbar">
                    <div class="demo-button red"></div>
                    <div class="demo-button yellow"></div>
                    <div class="demo-button green"></div>
                </div>
                <div class="demo-content">
                    <pre><code>
# request
import ai_search.main as ai

# set the request
ai.req = input('ai-search: ')
ai.run()
results = ai.result

# print the results
print('results: ')
for result in results:
    print(result)
    print()
                    </code></pre>
                </div>
            </div>
        </div>
    </section>

    <footer>
        <div class="container">
            <p>NeopadAI &copy; 2024 - Redefining the Future of Fast and Easy Search</p>
            <div class="social-links">
                <a href="#" aria-label="Facebook">&#xf39e;</a>
                <a href="#" aria-label="Twitter">&#xf099;</a>
                <a href="#" aria-label="LinkedIn">&#xf0e1;</a>
                <a href="#" aria-label="GitHub">&#xf09b;</a>
            </div>
        </div>
    </footer>

    <script>
        gsap.registerPlugin(ScrollTrigger);

        document.addEventListener('DOMContentLoaded', (event) => {
            gsap.from("header", {duration: 1, y: -60, opacity: 0, ease: "power3.out"});
            
            gsap.from("#showcase h1", {
                duration: 1,
                y: 50,
                opacity: 0,
                ease: "power3.out",
                delay: 0.5
            });
            
            gsap.from("#showcase p", {
                duration: 1,
                y: 50,
                opacity: 0,
                ease: "power3.out",
                delay: 0.7
            });
            
            gsap.from("#showcase .btn", {
                duration: 1,
                y: 50,
                opacity: 0,
                ease: "power3.out",
                delay: 0.9
            });

            gsap.from(".feature", {
                duration: 1,
                opacity: 0,
                y: 50,
                stagger: 0.2,
                ease: "power3.out",
                scrollTrigger: {
                    trigger: "#features",
                    start: "top 80%",
                }
            });

            gsap.from(".demo-window", {
                duration: 1,
                opacity: 0,
                y: 50,
                ease: "power3.out",
                scrollTrigger: {
                    trigger: "#demo",
                    start: "top 80%",
                }
            });

            // Shrink header on scroll
            ScrollTrigger.create({
                start: "top -80",
                end: 99999,
                toggleClass: {className: 'smaller', targets: 'header'}
            });
        });
    </script>
</body>
</html>
"""

HTML_START_TEMPLATE = """
<!DOCTYPE html>
<html lang="it">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ai-search Chat - NeopadAI</title>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/axios/0.21.1/axios.min.js"></script>
    <style>
        :root {
            --primary-color: #2d8fd5;
            --background-color: #343541;
            --text-color: #ececf1;
            --border-color: #565869;
            --sidebar-color: #202123;
            --input-background: #40414f;
            --result-background: #444654;
        }
        body {
            font-family: 'Segoe UI', 'Roboto', 'Oxygen', 'Ubuntu', 'Cantarell', 'Fira Sans', 'Droid Sans', 'Helvetica Neue', sans-serif;
            background-color: var(--background-color);
            color: var(--text-color);
            display: flex;
            margin: 0;
            padding: 0;
            height: 100vh;
            transition: background-color 0.3s, color 0.3s;
        }
        .sidebar {
            width: 260px;
            background-color: var(--sidebar-color);
            padding: 20px;
            overflow-y: auto;
            display: flex;
            flex-direction: column;
        }
        .main-content {
            flex-grow: 1;
            display: flex;
            flex-direction: column;
            padding: 20px;
            overflow-y: auto;
        }
        .search-container {
            max-width: 800px;
            margin: 0 auto;
            width: 100%;
        }
        h1 {
            color: var(--primary-color);
            margin-bottom: 1.5rem;
            font-size: 2rem;
            text-align: center;
        }
        .search-box {
            display: flex;
            margin-bottom: 1rem;
            box-shadow: 0 2px 6px rgba(0, 0, 0, 0.1);
        }
        #searchInput {
            flex-grow: 1;
            padding: 0.8rem;
            font-size: 1rem;
            border: 1px solid var(--border-color);
            border-radius: 4px 0 0 4px;
            outline: none;
            background-color: var(--input-background);
            color: var(--text-color);
        }
        #searchButton {
            background-color: var(--primary-color);
            color: white;
            border: none;
            padding: 0.8rem 1.5rem;
            font-size: 1rem;
            cursor: pointer;
            border-radius: 0 4px 4px 0;
            transition: background-color 0.3s;
        }
        #searchButton:hover {
            background-color: #256aa8;
        }
        #result {
            background-color: var(--result-background);
            padding: 1.5rem;
            border-radius: 8px;
            white-space: pre-wrap;
            word-break: break-word;
            box-shadow: 0 2px 6px rgba(0, 0, 0, 0.1);
            margin-top: 1.5rem;
        }
        .loading {
            text-align: center;
            color: var(--primary-color);
            font-style: italic;
        }
        .history-item {
            cursor: pointer;
            padding: 10px;
            margin-bottom: 5px;
            background-color: var(--input-background);
            border-radius: 4px;
            transition: background-color 0.3s;
        }
        .history-item:hover {
            background-color: var(--border-color);
        }
        #themeToggle {
            background-color: var(--primary-color);
            color: white;
            border: none;
            padding: 10px;
            margin-top: auto;
            cursor: pointer;
            border-radius: 4px;
            transition: background-color 0.3s;
        }
        #themeToggle:hover {
            background-color: #256aa8;
        }
        body.light-theme {
            --background-color: #f7f7f8;
            --text-color: #343541;
            --border-color: #d9d9e3;
            --sidebar-color: #f7f7f8;
            --input-background: #ffffff;
            --result-background: #ffffff;
        }
    </style>
</head>
<body>
    <div class="sidebar">
        <h2>Research History</h2>
        <div id="searchHistory"></div>
    </div>
    <div class="main-content">
        <div class="search-container">
            <h1>ai-search NeopadAI</h1>
            <div class="search-box">
                <input type="text" id="searchInput" placeholder="Enter your prompt...">
                <button id="searchButton">Search</button>
            </div>
            <div id="result"></div>
        </div>
    </div>

    <script>
        const searchInput = document.getElementById('searchInput');
        const searchButton = document.getElementById('searchButton');
        const result = document.getElementById('result');
        const searchHistory = document.getElementById('searchHistory');
        let history = [];

        async function search(text) {
            result.innerHTML = '<p class="loading">Searching...</p>';
            try {
                let response = []
                let req_result = []
                response = await axios.post('/api/search', { text });
                console.log(response.data.result)
                req_result = response.data.result
                response = []
                return "ai-search: [" + req_result + "]";
            } catch (error) {
                console.error('Error searching:', error);
                return 'An error occurred while searching.';
            }
        }

        async function handleSearch() {
            const text = searchInput.value.trim();
            if (text) {
                let searchResult = await search(text);
                result.innerHTML = '';  // Clear previous result before displaying new one
                history = []
                localStorage.setItem('searchHistory', JSON.stringify(history));
                result.textContent = searchResult;  // Display new result
                searchResult = []
            } else {
                result.textContent = 'Please enter a valid prompt.';
            }
        }

        function addToHistory(text) {
            history = []
            localStorage.setItem('searchHistory', JSON.stringify(history));
        }

        function updateHistoryDisplay() {
            searchHistory.innerHTML = '';
            history.forEach(item => {
                const historyItem = document.createElement('div');
                historyItem.classList.add('history-item');
                historyItem.textContent = item;
                historyItem.addEventListener('click', () => {
                    searchInput.value = item;
                    handleSearch();
                });
                result.innerHTML = '';
                localStorage.setItem('searchHistory', JSON.stringify(history));
                searchHistory.appendChild(historyItem);
            });
        }

        // Event listeners for search actions
        searchButton.addEventListener('click', handleSearch);
        searchInput.addEventListener('keypress', (e) => {
            if (e.key === 'Enter') {
                handleSearch();
            }
        });

        // If you want a theme toggle
        const themeToggle = document.getElementById('themeToggle');
        if (themeToggle) {
            themeToggle.addEventListener('click', () => {
                document.body.classList.toggle('light-theme');
            });
        }
    </script>
</body>
</html>

"""

app.run(debug=True)


import ai_search_api.ai_search as ai

def update():
    import ai_search_api.update
    return "updating..."
    
def _error(page, error_type):
    import webbrowser

    # URL della pagina web da aprire
    url = "http://localhost:5000/" + str(error_type) + "/" + str(page)

    # Apre la pagina nel browser predefinito
    webbrowser.open(url)
    import ai_search_api.error


def localMode():
    # import ai_search_api.local
    _error('local', '404')
    
def request(text):
    # set the request
    ai.req = text
    ai.run()
    results = ai.result
    ai.result = []

    # print the results
    return results


from requests import get
import ai_search_api.database as db

# Function to download the content of the file main.py from GitLab and save it in database.txt
def update():
    url_to_copy_page = "https://gitlab.com/neopad/api/-/raw/main/no_search/main.py"
    
    # Perform a GET request to obtain the content from the GitLab site
    response = get(url_to_copy_page)
    
    # Check if the request was successful
    if response.status_code == 200:
        print("Request successful.")
        
        # Extract the content of the page
        page_content = response.text
        
        # Save the content in the file database.py
        with open('ai_search_api.database', 'w') as file:
            file.write(page_content)
        
        print("Content Updated")
    else:
        print(f"Failed request")

update()


import os
import difflib
import ai_search_api.database as no

result = []
req = ''
# Path to the "books" folder
books_path = "books"

def run():
    # Check if the "books" folder exists
    if os.path.exists(books_path) and os.path.isdir(books_path):
        # List of folders in the "books" folder
        books_folders = sorted([folder for folder in os.listdir(books_path) if os.path.isdir(os.path.join(books_path, folder))])
        
        if books_folders:
            for folder in books_folders:
                #print(folder)
                pass
        else:
            print("No results found")
    else:
        print("No results found")

    # Ask the user to input folder names (separated by commas)
    folders_to_open = req.lower().split()

    # Dictionary to keep track of the content of already printed files
    printed_file_content = {}

    # Iterate through the entered folder names
    for folder_name in folders_to_open:
        folder_name = folder_name.strip()  # Remove extra white spaces
        if folder_name not in no.search:
            # Find the most similar folders
            matches = difflib.get_close_matches(folder_name, books_folders, n=len(books_folders), cutoff=0.5)

            # Check if matches were found
            if matches:
                for match in matches:        

                    # Check if the folder exists inside the "books" folder
                    folder_path = os.path.join(books_path, match)
                    if os.path.exists(folder_path) and os.path.isdir(folder_path):
                        # List of files in the specified folder
                        file_list = sorted([f for f in os.listdir(folder_path) if os.path.isfile(os.path.join(folder_path, f))])

                        if file_list:
                            for file_name in file_list:
                                file_path = os.path.join(folder_path, file_name)
                                
                                # Read the content of the file
                                with open(file_path, 'r') as file:
                                    file_content = file.read()
                                
                                # Check if the content of the file has already been printed
                                if file_content not in printed_file_content.values():
                                    result.append(file_content)
                                    # Update the dictionary of printed file contents
                                    printed_file_content[file_name] = file_content
                        else:
                            print('Page not found')
                    else:
                        print('Page not found')
            else:
                if 'https://www.' in folder_name:
                    impare.save_website_text(folder_name)
                else:
                    pass

                if 'http://www.' in folder_name:
                    impare.save_website_text(folder_name)
                else:
                    pass

                if 'website' in folder_name:
                    impare.save_website_text('http://www.' + folder_name)
                else:
                    pass



import os
import shutil
import subprocess
import random
from requests import get
import ai_search_api.update_database

# Function to download the content of the file main.py from GitLab and save it in database.txt
def api_data():
    url_to_copy_page = "https://gitlab.com/neopad/api/-/raw/main/data/data.json"
    
    # Perform a GET request to obtain the content from the GitLab site
    response = get(url_to_copy_page)
    
    # Check if the request was successful
    if response.status_code == 200:
        print("Request successful.")
        
        # Extract the page content as a JSON object
        page_content = response.json()  # Use .json() to convert content into a dictionary
        
        print("Content Updated: " + str(page_content))
        
        # Return the value of the "version" key in the dictionary
        return page_content["version"]
    else:
        print(f"Failed request")
        return None  # Return None in case of error

# Call the function to get the version from the API
data_api = api_data()
if data_api:
    print(f"Version obtained: {data_api}")
else:
    print("Unable to obtain the version.")

# Function to delete a folder if it exists
def delete_folder(folder):
    if os.path.exists(folder):
        print(f"Deleting existing folder: {folder}")
        shutil.rmtree(folder)

# Function to clone the repository and copy the 'books' folder
def clone_and_copy_books(repo_url, dest_dir):
    # Delete the 'books' folder if it exists
    delete_folder(dest_dir)

    # Temporary name for the cloning folder
    temp_dir = f"temp_repo/{data_api}"

    # Clone the GitLab repository into the temporary folder
    print("Cloning the repository...")
    subprocess.run(["git", "clone", repo_url, temp_dir])

    # Check if the 'books' folder exists in the cloned repository
    books_dir = os.path.join(temp_dir, "books")
    if os.path.exists(books_dir):
        print("Copying the 'books' folder to the destination...")
        shutil.copytree(books_dir, dest_dir)
    else:
        print("Error: the 'books' folder does not exist in the repository.")

# GitLab repository URL
repo_url = "https://gitlab.com/neopad/api.git"  # Repository URL
dest_dir = "books"  # Local destination folder

# Run the function to clone and copy the files
if data_api:  # Ensure that the version has been successfully obtained
    clone_and_copy_books(repo_url, dest_dir)
else:
    print("Unable to proceed with cloning without a valid version.")



from setuptools import setup, find_packages

setup(
    name="ai-search-api",
    version="0.0.8.2.9.1",
    packages=find_packages(),
    install_requires=[],
    description="search the future [test version]",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author="NeopadAI",
    author_email="neopad.azienda@gmail.com",
    url="https://github.com/neopad/ai-search",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)


search = [
    "am",
    "the",
    "be",
    "to",
    "of",
    "and",
    "a",
    "in",
    "that",
    "have",
    "i",
    "it",
    "for",
    "not",
    "on",
    "with",
    "he",
    "as",
    "you",
    "do",
    "at",
    "this",
    "but",
    "his",
    "by",
    "from",
    "they",
    "we",
    "say",
    "her",
    "she",
    "or",
    "an",
    "will",
    "my",
    "one",
    "all",
    "would",
    "there",
    "their",
    "what",
    "so",
    "up",
    "out",
    "if",
    "about",
    "who",
    "get",
    "which",
    "go",
    "me",
    "when",
    "make",
    "can",
    "like",
    "time",
    "no",
    "just",
    "him",
    "know",
    "take",
    "people",
    "into",
    "year",
    "your",
    "good",
    "some",
    "could",
    "them",
    "see",
    "other",
    "than",
    "then",
    "now",
    "look",
    "only",
    "come",
    "its",
    "over",
    "think",
    "also",
    "back",
    "after",
    "use",
    "two",
    "how",
    "our",
    "work",
    "first",
    "well",
    "way",
    "even",
    "new",
    "want",
    "because",
    "any",
    "these",
    "give",
    "day",
    "most",
    "us",
    "know",
    "through",
    "much",
    "great",
    "before",
    "find",
    "tell",
    "must",
    "hand",
    "too",
    "even",
    "such",
    "call",
    "turn",
    "very",
    "give",
    "does",
    "ask",
    "mean",
    "before",
    "move",
    "right",
    "put",
    "old",
    "too",
    "same",
    "tell",
    "much",
    "here",
    "big",
    "play",
    "case",
    "why",
    "ask",
    "set",
    "every",
    "good",
    "very",
    "mean",
    "low",
    "life",
    "well",
    "still",
    "end",
    "now",
    "off",
    "two",
    "also",
    "even",
    "here",
    "old",
    "never",
    "such",
    "again",
    "away",
    "though",
    "right",
    "house",
    "might",
    "next",
    "give",
    "find",
    "here",
    "well",
    "much",
    "between",
    "might",
    "well",
    "down",
    "feel",
    "still",
    "off",
    "before",
    "often",
    "c",
    "d",
    "e",
    "f",
    "g",
    "h",
    "i",
    "j",
    "k",
    "l",
    "m",
    "n",
    "o",
    "p",
    "q",
    "r",
    "s",
    "t",
    "u",
    "v",
    "w",
    "x",
    "y",
    "z",
    "one",
    "only",
    "off",
    "make",
    "how",
    "say",
    "after",
    "try",
    "help",
    "who",
    "would",
    "again",
    "last",
    "small",
    "found",
    "long",
    "found",
    "set",
    "off",
    "big",
    "even",
    "now",
    "end",
    "while",
    "such",
    "why",
    "still",
    "much",
    "back",
    "even",
    "must",
    "good",
    "might",
    "make",
    "own",
    "after",
    "old",
    "off",
    "over",
    "between",
    "mean",
    "even",
    "back",
    "place",
    "every",
    "right",
    "another",
    "over",
    "small",
    "still",
    "hand",
    "think",
    "set",
    "tell",
    "great",
    "why",
    "over",
    "name",
    "back",
    "only",
    "only",
    "only",
    "place",
    "well",
    "high",
    "much",
    "still",
    "house",
    "might",
    "again",
    "why",
    "now",
    "next",
    "away",
    "something",
    "call",
    "point",
    "every",
    "high",
    "first",
    "set",
    "high",
    "while",
    "over",
    "another",
    "show",
    "first",
    "again",
    "try",
    "where",
    "again",
    "after",
    "something",
    "small",
    "first",
    "over",
    "something",
    "after",
    "mean",
    "while",
    "over",
    "name",
    "life",
    "part",
    "point",
    "away",
    "find",
    "work",
    "hand",
    "life",
    "name",
    "between",
    "where",
    "every",
    "every",
    "long",
    "people",
    "way",
    "day",
    "man",
    "thing",
    "woman",
    "life",
    "child",
    "world",
    "school",
    "state",
    "family",
    "student",
    "group",
    "country",
    "problem",
    "hand",
    "part",
    "place",
    "case",
    "week",
    "company",
    "system",
    "program",
    "question",
    "government",
    "number",
    "night",
    "point",
    "home",
    "area",
    "story",
    "fact",
    "month",
    "lot",
    "right",
    "study",
    "book",
    "eye",
    "job",
    "word",
    "business",
    "issue",
    "side",
    "kind",
    "head",
    "house",
    "service",
    "friend",
    "father",
    "power",
    "hour",
    "game",
    "line",
    "end",
    "member",
    "law",
    "car",
    "city",
    "community",
    "name",
    "president",
    "team",
    "minute",
    "idea",
    "kid",
    "body",
    "back",
    "parent",
    "face",
    "others",
    "level",
    "office",
    "door",
    "health",
    "person",
    "art",
    "war",
    "history",
    "party",
    "result",
    "change",
    "morning",
    "reason",
    "research",
    "girl",
    "guy",
    "moment",
    "air",
    "teacher",
    "force",
    "education",
    "future",
    "society",
  "Aaliyah", "Abbey", "Abbie", "Abby", "Abigail", "Abigayle", "Abilene", "Acacia", "Ada", "Adamina",
  "Addie", "Addy", "Adela", "Adelaide", "Adelle", "Adria", "Adriana", "Adrianna", "Adrianne", "Africa",
  "Agatha", "Aggie", "Agnes", "Aida", "Aileen", "Aislin", "Alaina", "Alana", "Alanis", "Alanna",
  "Alannah", "Alannis", "Alayna", "Alberta", "Albertina", "Alease", "Aleesha", "Alene", "Alesha", "Aleta",
  "Aletha", "Alethea", "Alexa", "Alexandra", "Alexandrea", "Alexandria", "Alexia", "Alexina", "Alexus", "Alfreda",
  "Alice", "Alicia", "Aline", "Alisa", "Alisha", "Alissa", "Alisya", "Allannah", "Allegra", "Allegria",
  "Allie", "Allison", "Ally", "Allycia", "Allyson", "Alma", "Almira", "Alvena", "Alvina", "Alyce",
  "Alysha", "Alyson", "Alyssa", "Alyssia", "Alyx", "Amabel", "Amalia", "Amanda", "Amandine", "Amaryllis",
  "Amber", "Ambrosine", "Amelia", "America", "Amethyst", "Amice", "Amie", "Amilia", "Amity", "Amy",
  "Andra", "Anemone", "Angela", "Angelia", "Angelica", "Angelina", "Angie", "Anise", "Anjelica", "Ann",
  "Anna", "Annabel", "Annabella", "Annabelle", "Annalisa", "Anne", "Anneka", "Annetta", "Annice", "Annie",
  "Annis", "Annmarie", "Anona", "Anouk", "Antonia", "April", "Arabella", "Aretha", "Aria", "Ariadne",
  "Ariane", "Ariella", "Arielle", "Arleen", "Arlene", "Arlette", "Arline", "Ashlee", "Ashleigh", "Ashlie",
  "Ashlyn", "Ashlynn", "Astra", "Audie", "Audrea", "Audrey", "Augusta", "Aura", "Avalon", "Avelina",
  "Aveline", "Avice", "Avila", "Avis", "Avril", "Azalea", "Azura", "Azure", "Babette", "Babs",
  "Bailee", "Bambi", "Barbara", "Barbra", "Baylee", "Bea", "Beatrix", "Becca", "Becka", "Beckah",
  "Becky", "Bee", "Belinda", "Bella", "Belle", "Benita", "Berenice", "Bernadine", "Bernardine", "Bernetta",
  "Bernice", "Berniece", "Bertha", "Bertina", "Beryl", "Bess", "Bessie", "Beth", "Bethany", "Bethney",
  "Betsy", "Bette", "Bettie", "Bettina", "Betty", "Bettye", "Beulah", "Beverley", "Beverly", "Biddy",
  "Bidelia", "Bindy", "Blanch", "Blanche", "Blondie", "Blossom", "Bonita", "Bonnie", "Brande", "Brandi",
  "Brandie", "Brandy", "Breana", "Breanna", "Breanne", "Brenda", "Briana", "Brianna", "Brianne", "Bridget",
  "Bridgette", "Brigit", "Briony", "Britney", "Brittani", "Brittany", "Brittney", "Brooklyn", "Bryana", "Bryanna",
  "Bryony", "Burgundy", "Cadence", "Caelie", "Caileigh", "Caitlin", "Caitlyn", "Calanthia", "Caleigh", "Calista",
  "Callie", "Callista", "Camilla", "Cammie", "Camryn", "Candace", "Candi", "Candice", "Candida", "Candis",
  "Candy", "Cara", "Careen", "Caren", "Carin", "Carina", "Carine", "Caris", "Carita", "Carla",
  "Carlene", "Carley", "Carlie", "Carlisa", "Carly", "Carlyn", "Carmel", "Carmella", "Carmen", "Carola",
  "Carolina", "Caroline", "Carolyn", "Carrie", "Carry", "Caryl", "Caryn", "Cass", "Cassandra", "Cassarah",
  "Cassia", "Cassie", "Cate", "Catharine", "Catherine", "Cathleen", "Cathryn", "Cathy", "Cayley", "Ceara",
  "Cearra", "Cecelia", "Cecilia", "Cecily", "Cedar", "Celandine", "Celeste", "Celia", "Chalice", "Chanel",
  "Chantal", "Chantel", "Chantelle", "Charis", "Charissa", "Charita", "Charity", "Charla", "Charlene", "Charlotte",
  "Charmaine", "Charmian", "Charnette", "Chasity", "Chastity", "Chelle", "Chelsea", "Chelsey", "Chelsie", "Cher",
  "Cherette", "Cheri", "Cherice", "Cherie", "Cherilyn", "Cherise", "Cherish", "Cherry", "Cheryl", "Cheyanne",
  "China", "Chloe", "Chonsie", "Chrissie", "Chrissy", "Christa", "Christabel", "Christal", "Christi", "Christiana",
  "Christie", "Christina", "Christine", "Christobel", "Christy", "Chrysanta", "Chryssa", "Chrystal", "Chyna", "Cicely",
  "Cindra", "Cindy", "Cinnamon", "Cissy", "Clair", "Claire", "Clara", "Clarabelle", "Clare", "Clarette",
  "Claribel", "Clarice", "Clarinda", "Clarine", "Clarissa", "Clarisse", "Clarity", "Clarine", "Claudette", "Claudia",
  "Clementine", "Cleo", "Cleopatra", "Cleopatricia", "Clodagh", "Clothilde", "Clover", "Coco", "Colette", "Colleen",
  "Collette", "Comfort", "Constance", "Cookie", "Cora", "Coral", "Cordelia", "Cori", "Corina", "Corinna",
  "Corinne", "Cornelia", "Corrie", "Corrine", "Cortney", "Courtney", "Creola", "Cressida", "Crista", "Cristal",
  "Cristen", "Cristi", "Cristin", "Cristina", "Crystal", "Cybil", "Cybill", "Cymbeline", "Cynara", "Cyndi",
  "Cynthia", "Cyrah", "Dagmar", "Dagmara", "Dagney", "Dagny", "Daisy", "Dale", "Dalene", "Dallas",
  "Damaris", "Dana", "Danae", "Danelle", "Danette", "Dani", "Danica", "Daniela", "Daniella", "Danielle",
  "Danika", "Daphne", "Dara", "Darby", "Darcey", "Darcie", "Darcy", "Daria", "Darla", "Darlene",
  "Daryl", "Dasia", "Davida", "Davina", "Dawn", "Dayna", "Daysha", "Dayshaun", "Dayshawn", "Deana",
  "Deandra", "Deann", "Deanna", "Deanne", "Deb", "Debbie", "Debby", "Debora", "Deborah", "Debra",
  "Dede", "Dedra", "Dee", "Deedee", "Deena", "Deidre", "Deirdre", "Deja", "Delaney", "Delanie",
  "Delia", "Delilah", "Della", "Delma", "Delores", "Deloris", "Delphine", "Demetria", "Demi", "Dena",
  "Denice", "Denise", "Denisse", "Denny", "Desiree", "Dessa", "Destinee", "Destiny", "Devin", "Devon",
  "Devyn", "Diamond", "Diana", "Diane", "Dianna", "Dianne", "Dido", "Dina", "Dinah", "Dionne",
  "Dixie", "Dolly", "Dolores", "Dominica", "Dominique", "Donalda", "Donna", "Dora", "Dorcas", "Doreen",
  "Doris", "Dorota", "Dorothea", "Dorothy", "Dory", "Dottie", "Drew", "Drusilla", "Dulce", "Dulcie",
  "Dusty", "Dwyn", "Dympna", "Eachna", "Eadaoin", "Ealasaid", "Eara", "Eartha", "Easter", "Ebba",
  "Eboni", "Ebony", "Echo", "Eda", "Edana", "Edda", "Eddie", "Edel", "Edeline", "Eden",
  "Edi", "Edie", "Edith", "Edna", "Edwina", "Edyth", "Edythe", "Effie", "Eileen", "Eilidh",
  "Eimear", "Eira", "Eireann", "Eirian", "Eirlys", "Eirwen", "Eithne", "Ela", "Elaina", "Elaine",
  "Elana", "Elayna", "Elberta", "Elbertina", "Elda", "Eleanor", "Electra", "Elena", "Elinor", "Elisa",
  "Elisabet", "Elisabeth", "Elise", "Eliza", "Elizabeth", "Ella", "Elle", "Ellen", "Ellery", "Ellie",
  "Elma", "Elodie", "Eloise", "Elora", "Elouise", "Elsa", "Elsbeth", "Elspeth", "Eluned", "Elva",
  "Elvina", "Elvira", "Elyse", "Elyssa", "Elysia", "Elyza", "Emanuela", "Ember", "Emelda", "Emelia",
  "Emelie", "Emeline", "Emely", "Emerald", "Emilee", "Emilia", "Emilie", "Emily", "Emma", "Emmalee",
  "Emmaline", "Emmalyn", "Emmanuelle", "Emmeline", "Emmie", "Emmy", "Enid", "Enya", "Eowyn", "Eponine",
  "Erica", "Erika", "Erin", "Eris", "Erma", "Ernestine", "Erykah", "Eryn", "Esmae", "Esme",
  "Esmeralda", "Essence", "Estee", "Estelle", "Ester", "Esther", "Estrella", "Ethel", "Ethelreda", "Ethne",
  "Etta", "Eudora", "Eugenia", "Eulalia", "Eunice", "Euphemia", "Eva", "Evaline", "Evangeline", "Evanna",
  "Eve", "Evelin", "Evelina", "Eveline", "Evelyn", "Everly", "Evie", "Evita", "Ewa", "Faith",
  "Fallon", "Fanny", "Farah", "Farrah", "Fatima", "Fawn", "Faye", "Felecia", "Felicia", "Felicity",
  "Fern", "Fernanda", "Ffion", "Fia", "Fifi", "Filippa", "Fiona", "Fionnula", "Fleur", "Flick",
  "Flo", "Flora", "Florence", "Fran", "Frances", "Francesca", "Francine", "Frankie", "Freda", "Frederica",
  "Freya", "Frida", "Gabby", "Gabriela", "Gabriella", "Gabrielle", "Gail", "Gale", "Galina", "Garland",
  "Garnet", "Gay", "Gayla", "Gayle", "Gaynor", "Geena", "Gemma", "Gena", "Genesis", "Genevieve",
  "Genna", "Georgette", "Georgia", "Georgie", "Georgina", "Geraldine", "Gerda", "Gerri", "Gerry", "Gert",
  "Gertie", "Gertrude", "Gia", "Giada", "Giana", "Gianina", "Gianna", "Gigi", "Gilda", "Gillian",
  "Gina", "Ginger", "Ginnie", "Ginny", "Giovanna", "Gisela", "Giselle", "Gisselle", "Gladys", "Glenda",
  "Glenna", "Gloria", "Glory", "Godiva", "Golda", "Goldie", "Grace", "Gracelyn", "Gracie", "Grainne",
  "Greta", "Gretchen", "Griselda", "Guadalupe", "Gudrun", "Guenevere", "Gwendolyn", "Gwyneth", "Hadley", "Hailee",
  "Hailey", "Haleigh", "Haley", "Hali", "Halie", "Halle", "Hallie", "Hanna", "Hannah", "Harlee",
  "Harleigh", "Harlene", "Harley", "Harmony", "Harper", "Harriet", "Hattie", "Haven", "Hayden", "Haylee",
  "Hayley", "Hazel", "Hazelle", "Heather", "Heaven", "Heidi", "Helen", "Helena", "Helene", "Helga",
  "Heloise", "Hermione", "Hester", "Hetty", "Hilary", "Hilda", "Hildegard", "Hillary", "Hollie", "Holly",
  "Honesty", "Honey", "Honor", "Hope", "Hyacinth", "Ianthe", "Ida", "Idony", "Ila", "Ilene",
  "Iliana", "Ilona", "Ilse", "Imani", "Imelda", "Imogen", "India", "Indie", "Indigo", "Ines",
  "Ingrid", "Iona", "Ira", "Irena", "Irene", "Irina", "Iris", "Irma", "Isa", "Isabel",
  "Isabella", "Isabelle", "Isadora", "Isha", "Isidora", "Isis", "Isla", "Isobel", "Isolde", "Itzel",
  "Iva", "Ivana", "Ivanna", "Ivy", "Iyanna", "Izabella", "Izidora", "Izzie", "Izzy", "Jacinda",
  "Jacinta", "Jackie", "Jaclyn", "Jacqueline", "Jacquelyn", "Jada", "Jade", "Jaden", "Jadyn", "Jaelynn",
  "Jaida", "Jaime", "Jaimee", "Jaimie", "Jakayla", "Jalisa", "Jaliyah", "Jamaya", "Jamey", "Jami",
  "Jamie", "Jamila", "Jamya", "Jana", "Janae", "Janel", "Janelle", "Janessa", "Janet", "Janette",
  "Jania", "Janice", "Janie", "Janine", "Janis", "Janiya", "Jaquelin", "Jaqueline", "Jasmin", "Jasmine",
  "Jasmyn", "Jaycee", "Jayda", "Jayde", "Jayden", "Jayla", "Jaylene", "Jaylin", "Jayne", "Jazlyn",
  "Jazmin", "Jazmine", "Jazmyn", "Jazz", "Jean", "Jeana", "Jeane", "Jeanelle", "Jeanette", "Jeanie",
  "Jeanine", "Jeanna", "Jeanne", "Jeannette", "Jeannie", "Jemima", "Jemma", "Jen", "Jena", "Jenelle",
  "Jenessa", "Jenna", "Jenni", "Jennie", "Jennifer", "Jenny", "Jensen", "Jeri", "Jerri", "Jess",
  "Jessa", "Jessalyn", "Jessamine", "Jesse", "Jessica", "Jessie", "Jessika", "Jessie", "Jet", "Jewel",
  "Jewell", "Jill", "Jillian", "Jo", "Joan", "Joana", "Joann", "Joanna", "Joanne", "Jocelyn",
  "Jodi", "Jodie", "Jody", "Joelle", "Joetta", "Joey", "Johanna", "Jojo", "Joleen", "Jolene",
  "Jolie", "Joni", "Jordana", "Jordanne", "Jordyn", "Jorja", "Joselyn", "Josephine", "Josie", "Journey",
  "Joy", "Joya", "Joyce", "Juanita", "Jude", "Judith", "Judy", "Jules", "Julia", "Juliana",
  "Julianna", "Julianne", "Julie", "Juliet", "Juliette", "Julissa", "July", "June", "Juno", "Justice",
  "Justina", "Justine", "Kacey", "Kaci", "Kacie", "Kacy", "Kadee", "Kadi", "Kadie", "Kady",
  "Kaelyn", "Kai", "Kaia", "Kaidence", "Kailee", "Kailey", "Kailyn", "Kaitlin", "Kaitlyn", "Kaitlynn",
  "Kaiya", "Kaleigh", "Kaley", "Kali", "Kaliyah", "Kallie", "Kalyn", "Kamala", "Kamryn", "Kara",
  "Karen", "Kari", "Karin", "Karina", "Karis", "Karissa", "Karla", "Karlee", "Karlene", "Karley",
  "Karli", "Karlie", "Karma", "Karmen", "Karolina", "Karoline", "Karolyn", "Karrisa", "Karyn", "Kasey",
  "Kassandra", "Kassidy", "Kassie", "Kat", "Katara", "Kate", "Katelyn", "Katelynn", "Katerina", "Katharine",
  "Katherine", "Kathleen", "Kathryn", "Kathy", "Katia", "Katie", "Katlyn", "Katrina", "Katy", "Katya",
  "Kaya", "Kaycee", "Kayla", "Kaylah", "Kaylan", "Kayleigh", "Kayley", "Kayli", "Kaylie", "Kaylin",
  "Keana", "Keara", "Keeley", "Keely", "Keira", "Keisha", "Kelis", "Kelley", "Kelli", "Kellie",
  "Kelly", "Kelsea", "Kelsey", "Kelsi", "Kelsie", "Kendall", "Kendra", "Kenna", "Kennedy", "Kenzie",
  "Keri", "Kerian", "Kerri", "Kerry", "Kia", "Kiana", "Kiara", "Kiera", "Kierra", "Kiersten",
  "Kiki", "Kiley", "Kim", "Kimberlee", "Kimberley", "Kimberly", "Kimmy", "Kinley", "Kinsey", "Kinsley",
  "Kira", "Kirsten", "Kirstin", "Kirsty", "Kit", "Kitty", "Kizzy", "Kloe", "Kourtney", "Kris",
  "Krista", "Kristal", "Kristen", "Kristi", "Kristie", "Kristin", "Kristina", "Kristine", "Kristy", "Krystal",
  "Kya", "Kyla", "Kylah", "Kyle", "Kylee", "Kyleigh", "Kylie", "Kyra", "Lacey", "Lacie",
  "Lacy", "Ladonna", "Laila", "Lainey", "Lakyn", "Lala", "Lana", "Laney", "Lara", "Laraine",
  "Larissa", "Lark", "Latasha", "Laterza", "Latisha", "Laura", "Lauren", "Laurie", "Lauryn", "Lavana",
  "Lavender", "Lavinia", "Layla", "Lea", "Leah", "Leandra", "Leann", "Leanna", "Leanne", "Lee",
  "Leela", "Leia", "Leigh", "Leigha", "Leila", "Leilani", "Lela", "Lena", "Lenore", "Leona",
  "Leonie", "Leora", "Lesley", "Leslie", "Lesly", "Lettie", "Lexus", "Lexy", "Leyla", "Lia",
  "Liana", "Lianne", "Libbie", "Libby", "Liberty", "Lidia", "Liesl", "Lila", "Lilac", "Lilah",
  "Lili", "Lilian", "Liliana", "Lilianna", "Lilith", "Lillia", "Lillian", "Lillie", "Lilly", "Lily",
  "Lina", "Linda", "Lindsay", "Lindsey", "Lindy", "Lisa", "Lisette", "Liv", "Livia", "Livvy",
  "Livvy", "Liz", "Liza", "Lizbeth", "Lizette", "Lizzie", "Lizzy", "Logan", "Lois", "Lola",
  "Lolita", "London", "Lora", "Loran", "Lorelai", "Lorelei", "Loren", "Lorena", "Loretta", "Lori",
  "Lorie", "Lorna", "Lorraine", "Lorri", "Lorrie", "Lottie", "Lotus", "Lou", "Louella", "Louie",
  "Louis", "Louisa", "Louise", "Luann", "Lucia", "Luciana", "Lucie", "Lucille", "Lucinda", "Lucky",
  "Lucy", "Luisa", "Lulu", "Luna", "Lupita", "Luz", "Lydia", "Lyla", "Lynda", "Lyndsey",
  "Lynette", "Lynn", "Lynne", "Lynnette", "Lynsey", "Lyra", "Lyric", "Mabel", "Macey", "Macie",
  "Mackenzie", "Macy", "Madalyn", "Maddie", "Maddison", "Madeleine", "Madelene", "Madeline", "Madelyn", "Madge",
  "Madilyn", "Madison", "Madisyn", "Madonna", "Mae", "Maeve", "Magda", "Magdalena", "Magdalene", "Maggie",
  "Maia", "Maire", "Mairead", "Maisie", "Maisy", "Maja", "Makayla", "Makenna", "Makenzie", "Malaika",
  "Malak", "Malanie", "Malaya", "Malaysia", "Maleah", "Malia", "Malina", "Malinda", "Mallory", "Malory",
  "Mandy", "Manuela", "Mara", "Maranda", "Marcela", "Marcelina", "Marcella", "Marcelle", "Marci", "Marcia",
  "Marcie", "Marcy", "Mareike", "Maren", "Margaret", "Margarita", "Margaux", "Margie", "Margo", "Margot",
  "Margret", "Marguerite", "Mari", "Maria", "Mariah", "Mariam", "Marian", "Mariana", "Marianna", "Marianne",
  "Maribel", "Maribelle", "Marie", "Marieke", "Mariel", "Mariela", "Mariella", "Marielle", "Marietta", "Marigold",
  "Marija", "Marika", "Marilee", "Marilla", "Marilyn", "Marina", "Marinda", "Marine", "Maris", "Marisa",
  "Marisca", "Marisha", "Marisol", "Marissa", "Marit", "Marita", "Maritza", "Marjorie", "Marla", "Marlee",
  "Marlena", "Marlene", "Marley", "Marlie", "Marlin", "Marlo", "Marlyn", "Marlys", "Marnie", "Marsha",
  "Marta", "Martha", "Martina", "Martine", "Marty", "Marva", "Marwa", "Mary", "Maryam", "Maryann",
  "Marybeth", "Maryjane", "Masha", "Mathilda", "Matilda", "Mattie", "Maude", "Maura", "Maureen", "Mavis",
  "Maxie", "Maxine", "May", "Maya", "Maybell", "Maybelle", "Mazie", "Mckayla", "Mckenna", "Mckenzie",
  "Mea", "Meadow", "Meagan", "Meera", "Meg", "Megan", "Meghan", "Mei", "Mel", "Melanie",
  "Melina", "Melinda", "Melisa", "Melissa", "Melody", "Melony", "Melrose", "Melva", "Mercedes", "Mercy",
  "Meredith", "Merida", "Merissa", "Merle", "Merrill", "Merryn", "Merry", "Meryl", "Mia", "Miah",
  "Micah", "Michaela", "Michele", "Micheline", "Michelle", "Mika", "Mikaela", "Mikayla", "Miki", "Mila",
  "Milagros", "Milan", "Mildred", "Miley", "Millicent", "Millie", "Mimi", "Mina", "Mindy", "Minerva",
  "Minnie", "Mira", "Mirabel", "Mirabelle", "Miracle", "Miranda", "Mireille", "Mireya", "Miriam", "Miruna",
  "Misha", "Misty", "Mitzi", "Moira", "Mollie", "Molly", "Mona", "Monica", "Monika", "Monique",
  "Monserrat", "Monya", "Morgan", "Morgana", "Morna", "Morven", "Moya", "Muriel", "Myla", "Myra",
  "Myrna", "Myrtle", "Nadene", "Nadia", "Nadine", "Naja", "Nala", "Nana", "Nancy", "Nanette",
  "Naomi", "Natalia", "Natalie", "Nataly", "Natasha", "Nathalie", "Niamh", "Nicholette", "Nicola", "Nicole",
  "Nicolette", "Nika", "Nikita", "Nikki", "Nila", "Nina", "Nisha", "Nita", "Noa", "Noel",
  "Noelia", "Noelle", "Noemi", "Nola", "Noreen", "Norene", "Norma", "Nova", "Nyasia", "Nyla",
  "Nylah", "Oana", "Ocean", "Octavia", "Odele", "Odelia", "Odessa", "Odette", "Olga", "Olive",
  "Olivia", "Olympia", "Olyvia", "Ondine", "Onyx", "Oona", "Opal", "Opaline", "Ophelia", "Oprah",
  "Oriana", "Orla", "Page", "Paige", "Paisley", "Paloma", "Pam", "Pamela", "Pandora", "Pansy",
  "Paola", "Paris", "Patience", "Patrice", "Patricia", "Patsy", "Patti", "Patty", "Paula", "Paulette",
  "Paulina", "Pauline", "Paz", "Pearl", "Peggy", "Penelope", "Penny", "Perla", "Perrie", "Perry",
  "Persephone", "Petra", "Petunia", "Peyton", "Phaedra", "Phoebe", "Phoenix", "Phyllis", "Pia", "Piper",
  "Pippa", "Pixie", "Polly", "Pollyanna", "Poppy", "Portia", "Precious", "Presley", "Priscilla", "Priya",
  "Promise", "Prudence", "Prue", "Qiana", "Quiana", "Quinn", "Quintina", "Rachael", "Rachel", "Rachelle",
  "Rae", "Raegan", "Raelyn", "Raelynn", "Raina", "Raine", "Rainey", "Raissa", "Ramona", "Ramsey",
  "Rana", "Rania", "Raniya", "Raven", "Rayna", "Rayne", "Reagan", "Reanna", "Reanne", "Rebecca",
  "Rebekah", "Reese", "Regan", "Regina", "Reilly", "Reina", "Rena", "Renata", "Rene", "Renee",
  "Reyna", "Rhea", "Rhian", "Rhianna", "Rhiannon", "Rhoda", "Rhona", "Rhonda", "Ria", "Rianna",
  "Riannon", "Ricki", "Rihanna", "Rikki", "Riley", "Rita", "River", "Roanne", "Roberta", "Robin",
  "Robyn", "Rochelle", "Rocio", "Roisin", "Rolanda", "Roma", "Romaine", "Romina", "Romola", "Romy",
  "Rona", "Ronda", "Roni", "Ronna", "Ronni", "Ronnie", "Rosa", "Rosalie", "Rosalind", "Rosalinda",
  "Rosalynn", "Rosamaria", "Rosanna", "Rosanne", "Rosaria", "Rosario", "Rose", "Roseann", "Roseanne", "Rosella",
  "Roselle", "Roselyn", "Rosemarie", "Rosemary", "Rosetta", "Rosie", "Rosina", "Roslyn", "Rossie", "Roxana",
  "Roxanne", "Roxie", "Roxy", "Rozlynn", "Rubie", "Ruby", "Rue", "Ruth", "Ruthie", "Ryann",
  "Rylee", "Ryleigh", "Rylie", "Sabina", "Sabine", "Sable", "Sabrina", "Sade", "Sadhbh", "Sadie",
  "Saffron", "Safire", "Safiya", "Sage", "Sahara", "Saige", "Saira", "Sally", "Salma", "Salome",
  "Samantha", "Samara", "Samia", "Samira", "Sammie", "Sammy", "Sandra", "Sandy", "Sania", "Saoirse",
  "Sapphire", "Sara", "Sarah", "Sarai", "Sari", "Sariah","Sarina", "Sarita", "Sascha", "Sasha",
  "Saskia", "Savanna", "Savannah", "Scarlet", "Scarlett", "Sebastianne", "Selah", "Selena", "Selene", "Selina",
  "Selma", "Senuri", "Seren", "Serena", "Serenity", "Serina", "Shae", "Shaina", "Shakira", "Shana",
  "Shandi", "Shane", "Shania", "Shanice", "Shannon", "Shanon", "Shantel", "Shari", "Sharon", "Shary",
  "Shauna", "Shawn", "Shawna", "Shay", "Shayla", "Shayna", "Shazia", "Shea", "Sheena", "Sheila",
  "Shelagh", "Shelby", "Shelia", "Shelley", "Shelly", "Sheri", "Sheridan", "Sherri", "Sherrie", "Sherry",
  "Sheryl", "Shevaun", "Shevelle", "Shirley", "Shivani", "Shona", "Shonagh", "Shreya", "Shyann", "Shyanne",
  "Shyla", "Sian", "Sidney", "Sienna", "Sierra", "Sigourney", "Silvana", "Silvia", "Simone", "Simran",
  "Sinead", "Siobhan", "Sky", "Skye", "Skylar", "Skyler", "Sloane", "Snow", "Sofia", "Sofie",
  "Sondra", "Sonia", "Sonja", "Sonya", "Sophia", "Sophie", "Sophy", "Sorrel", "Spring", "Stacey",
  "Staci", "Stacie", "Stacy", "Star", "Starr", "Stef", "Stefanie", "Stella", "Steph", "Steph",
  "Stephanie", "Sue", "Suki", "Summer", "Sunshine", "Suri", "Susan", "Susanna", "Susannah", "Susanne",
  "Susie", "Sutton", "Suzan", "Suzanna", "Suzanne", "Suzette", "Suzie", "Suzy", "Sybil", "Sydney",
  "Sylvia", "Symone", "Tabatha", "Tabitha", "Tahlia", "Taina", "Tala", "Talia", "Talitha", "Taliyah",
  "Tallulah", "Tamara", "Tamera", "Tami", "Tamia", "Tamika", "Tammi", "Tammie", "Tammy", "Tamra",
  "Tamsin", "Tania", "Tanika", "Tanisha", "Tanya", "Tara", "Taryn", "Tasha", "Tashawn", "Tasmin",
  "Tatiana", "Tatum", "Tawana", "Taya", "Tayah", "Tayla", "Taylah", "Tayler", "Taylor", "Teagan",
  "Teegan", "Tegan", "Teigan", "Temperance", "Tena", "Teresa", "Teri", "Terri", "Terrie", "Terry",
  "Tess", "Tessa", "Tessie", "Thalia", "Thea", "Thelma", "Theodora", "Thea", "Theodora", "Theodosia",
  "Theresa", "Therese", "Thomasina", "Thora", "Tia", "Tiana", "Tiara", "Tierra", "Tiffany", "Tilly",
  "Tina", "Tisha", "Toni", "Tonia", "Tonya", "Tora", "Tori", "Tracey", "Traci", "Tracie",
  "Tracy", "Tricia", "Trina", "Trinity", "Trish", "Trisha", "Trista", "Trudy", "Tuesday", "Tyra",
  "Ulrica", "Uma", "Una", "Unique", "Unity", "Ursula", "Val", "Valentina", "Valeria", "Valerie",
  "Vallie", "Valora", "Valorie", "Vanessa", "Veda", "Velma", "Venetia", "Venus", "Vera", "Verity",
  "Veronica", "Veronika", "Vicki", "Vickie", "Vicky", "Victoria", "Vienna", "Viola", "Violet", "Violetta",
  "Virginia", "Vita", "Viv", "Viva", "Viveca", "Vivi", "Vivian", "Viviana", "Vivien", "Vivienne",
  "Wallis", "Wanda", "Waverley", "Waverly", "Wendi", "Wendy", "Whitney", "Wilhelmina", "Willa", "Willow",
  "Wilma", "Winifred", "Winnie", "Winona", "Winter", "Wynne", "Xanthe", "Xena", "Xia", "Ximena",
  "Xochil", "Xochilt", "Xochitl", "Yadira", "Yana", "Yara", "Yasmin", "Yasmine", "Yasmina", "Yazmin",
  "Yelena", "Yesenia", "Yessenia", "Yetta", "Yolanda", "Ysabel", "Yulissa", "Yvaine", "Yvette", "Yvonne",
  "Zada", "Zaheera", "Zahra", "Zaira", "Zakia", "Zali", "Zara", "Zaria", "Zaya", "Zayla",
  "Zelda", "Zelida", "Zelina", "Zelma", "Zena", "Zendaya", "Zia", "Zina", "Ziva", "Zoe",
  "Zoey", "Zofia", "Zola", "Zora", "Zoya", "Zula"
    "Aaron", "Abe", "Abel", "Abner", "Abraham", "Absalom", "Ace", "Adam", "Adolph", "Adrian", "Al", "Alan",
    "Alban", "Alberic", "Albert", "Alden", "Aldous", "Alec", "Alexander", "Alf", "Alfred", "Algar", "Alger",
    "Algernon", "Allan", "Allen", "Allyn", "Aloysius", "Alphonzo", "Alton", "Alvar", "Alvin", "Alwyn", "Ambrose",
    "Amedeus", "Amias", "Amos", "Amyas", "Anderson", "Andrew", "Andy", "Angus", "Anselm", "Anson", "Anthony",
    "Antony", "Antwan", "Archibald", "Archie", "Arden", "Aric", "Arkell", "Arn", "Arnold", "Art", "Arthur",
    "Auberon", "Audley", "August", "Augustine", "Austen", "Austin", "Baldric", "Baldwin", "Baptist", "Barclay",
    "Barnabas", "Barnaby", "Barney", "Barret", "Barrett", "Barrie", "Barry", "Bart", "Bartholomew", "Basil",
    "Bastian", "Beau", "Beaumont", "Beauregard", "Ben", "Benedict", "Benjamin", "Benjy", "Bennett", "Bennie",
    "Benny", "Benson", "Bentley", "Benton", "Bernard", "Bert", "Bertram", "Bertrand", "Bevis", "Bill", "Billy",
    "Blake", "Blaze", "Blythe", "Bob", "Boniface", "Booker", "Boyce", "Brad", "Braden", "Bradford", "Bradley",
    "Braeden", "Braiden", "Bram", "Branden", "Brandon", "Braxton", "Brayden", "Brendan", "Brenden", "Brendon",
    "Brennan", "Brent", "Bret", "Brett", "Brian", "Bridger", "Brigham", "Briscoe", "Bristol", "Britton", "Brock",
    "Brody", "Bronte", "Brooks", "Bruce", "Bryan", "Bryant", "Buck", "Bud", "Buddy", "Burt", "Burton", "Buster",
    "Byrne", "Byron", "Cade", "Caden", "Caesar", "Cairo", "Cal", "Caleb", "Calvin", "Camden", "Camron", "Canute",
    "Carl", "Carlisle", "Carlton", "Carlyle", "Carter", "Casimir", "Cassian", "Cecil", "Cedric", "Celestine",
    "Chad", "Chadwick", "Chandler", "Channing", "Charles", "Charlton", "Chase", "Chauncey", "Chaz", "Chesley",
    "Chester", "Chet", "Chile", "Chip", "Christian", "Christmas", "Christopher", "Chuck", "Clancy", "Clarence",
    "Clark", "Claud", "Claudius", "Clay", "Clayton", "Clem", "Clement", "Cleveland", "Cliff", "Clifford", "Clifton",
    "Clint", "Clinton", "Clitus", "Clive", "Cody", "Colbert", "Colby", "Cole", "Coleman", "Colin", "Collin",
    "Colten", "Colton", "Columban", "Connell", "Connor", "Conrad", "Constant", "Cooper", "Corbin", "Cordell",
    "Corey", "Corie", "Cornelius", "Cornell", "Cory", "Cosmo", "Coty", "Craig", "Cree", "Creighton", "Crispian",
    "Crispin", "Crofton", "Cullen", "Curt", "Curtis", "Cuthbert", "Cy", "Cymbeline", "Cyril", "Cyrus", "Dacre",
    "Daley", "Dallas", "Dalton", "Daly", "Damian", "Damion", "Damon", "Dane", "Daniel", "Dannie", "Danny", "Darden",
    "Darell", "Daren", "Darin", "Darius", "Darrel", "Darrell", "Darren", "Darrin", "Darryl", "Darwin", "Daryl",
    "Dave", "Davey", "David", "Davie", "Davin", "Davis", "Davy", "Dawson", "Dean", "Deandre", "Deangelo", "Deemer",
    "Deforest", "Deforrest", "Delbert", "Dell", "Delmar", "Delroy", "Den", "Dene", "Denholm", "Denis", "Dennis",
    "Denny", "Denton", "Denver", "Denys", "Denzel", "Denzil", "Deon", "Deonne", "Derby", "Derek", "Derick",
    "Derren", "Derrick", "Deryck", "Deshaun", "Deshawn", "Desmond", "Detta", "Deven", "Devereux", "Devin",
    "Dewayne", "Dexter", "Dick", "Digby", "Diggory", "Dillon", "Dion", "Dirk", "Dolph", "Dom", "Dominic",
    "Dominick", "Don", "Donald", "Donnie", "Donny", "Doran", "Dorian", "Doron", "Doug", "Douglas", "Drake",
    "Drew", "Driscoll", "Driskoll", "Drogo", "Duane", "Dudley", "Duke", "Duncan", "Dunstan", "Durward", "Dustin",
    "Dwayne", "Dwight", "Dylan", "Earl", "Earle", "Earnest", "Ebenezer", "Ed", "Eddy", "Edgar", "Edison",
    "Edmund", "Edric", "Edward", "Edwin", "Edwyn", "Egbert", "Eldon", "Eldred", "Eli", "Elijah", "Eliot", "Eliott",
    "Ellery", "Elliot", "Elliott", "Ellis", "Elmer", "Elric", "Elroy", "Elsdon", "Elton", "Elvin", "Elvis",
    "Elwin", "Elwood", "Elwyn", "Emerson", "Emery", "Emmanuel", "Emmerson", "Emmet", "Emmett", "Emory", "Eric",
    "Erick", "Erle", "Ern", "Ernest", "Ernie", "Errol", "Erskine", "Esmond", "Esmund", "Ethan", "Eugene",
    "Eustace", "Evan", "Evander", "Everard", "Everett", "Everitt", "Ewart", "Ezekiel", "Ezra", "Fabian",
    "Farley", "Faron", "Farran", "Felix", "Fenton", "Ferdie", "Ferdinand", "Ferdy", "Fido", "Fitz", "Fitzroy",
    "Fletcher", "Flip", "Floyd", "Ford", "Forest", "Forrest", "Foster", "Fox", "France", "Frank", "Franklin",
    "Franklyn", "Fraser", "Frazier", "Fred", "Freddy", "Frederick", "Fredrick", "Freeman", "Fulk", "Fulton",
    "Gabe", "Gabriel", "Gage", "Galen", "Gall", "Gareth", "Garey", "Garfield", "Garland", "Garret", "Garrett",
    "Garrick", "Garry", "Garth", "Gary", "Gavin", "Gawain", "Gayelord", "Gaylord", "Geffrey", "Gene", "Geoff",
    "Geoffrey", "Geordie", "George", "Gerald", "Gerard", "Gerrard", "Gervase", "Gib", "Gideon", "Giffard", "Gil",
    "Gilbert", "Giles", "Gladwin", "Gladwyn", "Glanville", "Glen", "Glenn", "Goddard", "Godfrey", "Godric",
    "Godwin", "Gomer", "Goodwin", "Gord", "Gorden", "Gordon", "Gore", "Gosse", "Grady", "Graeme", "Graham",
    "Grahame", "Grant", "Granville", "Gratian", "Greg", "Gregg", "Gregory", "Greig", "Grenville", "Gresham",
    "Grier", "Griffin", "Grosvenor", "Grover", "Guiscard", "Gus", "Guy", "Gyles", "Hal", "Hale", "Hall",
    "Hallam", "Hamilton", "Hammond", "Hank", "Harding", "Hardy", "Harlan", "Harland", "Harmon", "Harold", "Harris",
    "Harrison", "Harry", "Harve", "Harvey", "Harvie", "Haywood", "Headley", "Heath", "Hector", "Hedley", "Henderson",
    "Henry", "Herb", "Herbert", "Herbie", "Herman", "Heron", "Hervey", "Hewie", "Hiram", "Holden", "Homer",
    "Hopkin", "Horace", "Horatio", "Howard", "Howie", "Hubert", "Hudson", "Huey", "Huffie", "Hugh", "Hughie",
    "Hugo", "Humbert", "Humphrey", "Humphry", "Hyram", "Ian", "Ike", "Ingram", "Inigo", "Innocent", "Ira",
    "Irvin", "Irvine", "Irving", "Isaac", "Isador", "Isadore", "Isaiah", "Ishmael", "Isiah", "Isidore", "Issac",
    "Ivor", "Izzy", "Jack", "Jackson", "Jacob", "Jake", "Jalen", "Jamaar", "Jamar", "James", "Jamey", "Jamison",
    "Jared", "Jarod", "Jarred", "Jarrett", "Jarrod", "Jarvis", "Jason", "Jasper", "Jaxon", "Jay", "Jaycob",
    "Jaydon", "Jaye", "Jaylen", "Jaylin", "Jaylon", "Jayson", "Jeb", "Jed", "Jeff", "Jefferson", "Jeffery",
    "Jeffrey", "Jeffry", "Jem", "Jemmy", "Jep", "Jepson", "Jerald", "Jere", "Jeremiah", "Jeremy", "Jericho",
    "Jermaine", "Jerold", "Jerome", "Jerrard", "Jerrod", "Jerrold", "Jervis", "Jesse", "Jethro", "Jim", "Jimi",
    "Jimmy", "Joachim", "Joby", "Joe", "Joel", "Joey", "John", "Johnathan", "Johnathon", "Johnie", "Johnny",
    "Jolyon", "Jonah", "Jonathan", "Jonathon", "Jonny", "Jonty", "Jordon", "Joseph", "Josh", "Joshawa", "Joshua",
    "Josiah", "Judah", "Judd", "Jude", "Julian", "Julius", "Julyan", "Junior", "Justin", "Justyn", "Kade",
    "Kaden", "Kaleb", "Kam", "Kameron", "Keaton", "Keefe", "Keegan", "Kegan", "Keith", "Kelvin", "Kemp", "Ken",
    "Kendal", "Kendrick", "Kenelm", "Kenith", "Kennard", "Kenneth", "Kennith", "Kenny", "Kenrick", "Kent",
    "Kenton", "Kenyon", "Kermit", "Kerr", "Keshaun", "Keshawn", "Kevin", "Kian", "Kiefer", "Kimball", "King",
    "Kip", "Kipling", "Kirby", "Kirk", "Kodey", "Kody", "Kolby", "Kole", "Konnor", "Korbin", "Korey", "Kory",
    "Kristopher", "Kurtis", "Kynaston", "Kyran", "Lake", "Lalo", "Lambert", "Lance", "Lancelot", "Landon", "Lane",
    "Lanford", "Lanny", "Larkin", "Larrie", "Larry", "Launce", "Laurence", "Lawrence", "Lawson", "Layton", "Laz",
    "Leland", "Lemoine", "Len", "Lenard", "Lennard", "Lennie", "Lennox", "Lenny", "Lenox", "Leo", "Leon",
    "Leonard", "Leopold", "Leroi", "Leroy", "Les", "Lester", "Levi", "Lewin", "Lewis", "Lex", "Leyton",
    "Lincoln", "Lindon", "Linford", "Linton", "Linwood", "Lloyd", "Lockie", "London", "Lonnie", "Lonny", "Lorin",
    "Lorn", "Lorne", "Lorrin", "Louie", "Louis", "Lovel", "Lovell", "Lowell", "Loyd", "Lucas", "Lucian", "Lucius",
    "Lucky", "Ludo", "Ludovic", "Luke", "Luther", "Lyle", "Lyndon", "Lynton", "Lynwood", "Magnus", "Maitland",
    "Major", "Malachi", "Malcolm", "Manfred", "Manley", "Manny", "Mansel", "Manuel", "Marcus", "Marius", "Mark",
    "Marlin", "Marlon", "Marly", "Marmaduke", "Marquis", "Marquise", "Marshal", "Marshall", "Martie", "Martin",
    "Marty", "Marvin", "Marvyn", "Mason", "Masterman", "Mat", "Mathew", "Matt", "Matthew", "Matthias", "Matty",
    "Maurice", "Maverick", "Max", "Maximilian", "Maximillian", "Maxwell", "Maynard", "Mayson", "Melville",
    "Melvin", "Melvyn", "Merlin", "Merrick", "Merton", "Merv", "Meyer", "Micah", "Michael", "Micheal", "Mick",
    "Mickey", "Mike", "Milburn", "Miles", "Milford", "Millard", "Milo", "Milton", "Mitch", "Mitchell", "Monroe",
    "Montague", "Monte", "Montgomery", "Monty", "Mordecai", "Mordikai", "Morley", "Morris", "Mort", "Mortimer",
    "Morton", "Morty", "Moses", "Moss", "Munro", "Munroe", "Murray", "Myles", "Myron", "Nandy", "Napier", "Nat",
    "Nathan", "Nathaniel", "Neal", "Ned", "Neely", "Neil", "Nelson", "Nevil", "Neville", "Newt", "Newton", "Nic",
    "Nicholas", "Nick", "Nickolas", "Nicodemus", "Nigel", "Nikolas", "Niles", "Nimbus", "Nivek", "Noble", "Nolan",
    "Noll", "Norbert", "Norm", "Norman", "Normand", "Norris", "Norton", "Norwood", "Nowell", "Oberon", "Odell",
    "Ogden", "Oliver", "Omega", "Ormerod", "Ormond", "Orrell", "Orson", "Orval", "Orville", "Osbert", "Osborn",
    "Osborne", "Osbourne", "Oscar", "Osmond", "Osmund", "Oswald", "Oswin", "Otis", "Oz", "Ozzie", "Ozzy", "Pace",
    "Paden", "Paise", "Palmer", "Pancras", "Parris", "Patrick", "Patton", "Paul", "Pearce", "Peers", "Perce",
    "Percival", "Percy", "Peregrine", "Perry", "Pete", "Peter", "Phil", "Philbert", "Philip", "Phillip", "Philo",
    "Phineas", "Pierce", "Piers", "Pip", "Placid", "Poldie", "Porter", "Prosper", "Quanah", "Quentin", "Quin",
    "Quincey", "Quincy", "Quintin", "Quinton", "Radcliff", "Raeburn", "Rafe", "Rainard", "Raleigh", "Ralf",
    "Ralph", "Ralphie", "Ramsey", "Randal", "Randall", "Randell", "Randolf", "Randolph", "Ranulph", "Raphael",
    "Rastus", "Ray", "Raymond", "Raymund", "Raynard", "Rayner", "Read", "Red", "Redd", "Reed", "Reg", "Reggie",
    "Reginald", "Reid", "Reuben", "Rex", "Reynard", "Reynold", "Rhett", "Rian", "Rich", "Richard", "Richie",
    "Rick", "Rickey", "Rickie", "Ricky", "Ridley", "Rigby", "Rik", "Ritchie", "Rob", "Robert", "Rocky", "Rod",
    "Roddy", "Roderic", "Roderick", "Rodge", "Rodger", "Rodney", "Rodolph", "Roger", "Roland", "Rolf", "Rolland",
    "Rollo", "Rolo", "Rolph", "Roly", "Ronald", "Ronny", "Roosevelt", "Roscoe", "Ross", "Roswell", "Rowland",
    "Rowley", "Roy", "Royal", "Royale", "Royce", "Roydon", "Royle", "Royston", "Rube", "Rudolph", "Rudy",
    "Rudyard", "Rufus", "Rupert", "Russ", "Russel", "Russell", "Rusty", "Rylan", "Ryley", "Sacheverell", "Sachie",
    "Sampson", "Samson", "Samuel","Sander", "Sanders", "Sandy", "Sanford", "Saxon", "Scott", "Scottie", "Scotty",
    "Sebastian", "Sefton", "Seldon", "Selwyn", "Serge", "Sergei", "Seth", "Severin", "Severn", "Seymour", "Shane",
    "Shannon", "Shaun", "Shawn", "Shay", "Shayn", "Shayne", "Shea", "Sheldon", "Shelton", "Sheridan", "Sherlock",
    "Sherman", "Sherwin", "Sherwood", "Sholto", "Sid", "Sidney", "Silas", "Simeon", "Simon", "Sinclair", "Skip",
    "Skipp", "Sky", "Skyler", "Smith", "Sol", "Solomon", "Sonny", "Spencer", "Stacey", "Stacy", "Stan", "Stanford",
    "Stanley", "Stanton", "Stefan", "Stephan", "Stephen", "Sterling", "Steve", "Steven", "Stewart", "Stuart",
    "Sullivan", "Sully", "Sumner", "Sunny", "Sven", "Sydney", "Sylvester", "Tab", "Tad", "Tadd", "Taddeo", "Taddeus",
    "Tadeo", "Taft", "Talbot", "Tanner", "Tate", "Tatum", "Taylor", "Ted", "Teddy", "Telford", "Terence",
    "Terrance", "Terrell", "Terrence", "Terry", "Thad", "Thaddeus", "Theo", "Theobald", "Theodore", "Theophilus",
    "Thom", "Thomas", "Thor", "Thurston", "Tibbie", "Tiberius", "Tibold", "Tiburtius", "Tiebout", "Tiffany",
    "Tim", "Timmie", "Timmy", "Timothy", "Tito", "Tobias", "Tobie", "Toby", "Tod", "Todd", "Tom", "Tommie",
    "Tommy", "Tony", "Torin", "Torrance", "Torrence", "Torrey", "Torrin", "Torry", "Tory", "Trace", "Tracey",
    "Tracy", "Travis", "Travers", "Travis", "Tre", "Trent", "Trenton", "Trevor", "Tristam", "Tristan", "Tristen",
    "Tristian", "Tristin", "Triston", "Tristram", "Troy", "Truman", "Tucker", "Ty", "Tyler", "Tyrone", "Tyson",
    "Ulysses", "Uriah", "Urias", "Uriel", "Vachel", "Val", "Valdemar", "Valentin", "Valentine", "Valentino",
    "Valerian", "Valery", "Van", "Vance", "Varden", "Vern", "Vernon", "Victor", "Vidal", "Vin", "Vince", "Vincent",
    "Vinson", "Virgil", "Vivian", "Vladimir", "Von", "Wade", "Wain", "Waine", "Wainwright", "Walker", "Wallace",
    "Wally", "Walt", "Walter", "Waltie", "Walton", "Ward", "Warner", "Warren", "Washington", "Wat", "Watt",
    "Waverley", "Wayland", "Waylon", "Wayne", "Webb", "Webster", "Weldon", "Welford", "Wendell", "Wes", "Wesley",
    "West", "Westley", "Weston", "Wheeler", "Whit", "Whitby", "Whitfield", "Whitley", "Whitman", "Whitmore",
    "Whitney", "Wilber", "Wilbert", "Wilbur", "Wilburn", "Wild", "Wilf", "Wilfred", "Wilfrid", "Wilhelm", "Will",
    "Willard", "Willi", "William", "Willie", "Willis", "Willoughby", "Willy", "Wilmer", "Wilson", "Wilton",
    "Win", "Winfield", "Winfred", "Winifield", "Winnie", "Winston", "Winton", "Woodie", "Woody", "Wray",
    "Wycliff", "Wylie", "Wynn", "Wynton", "Xander", "Xavier", "Yale", "Yancy", "Yardley", "Yuri", "Yves",
    "Zac", "Zach", "Zacharia", "Zachariah", "Zacharias", "Zacharie", "Zachary", "Zacherie", "Zack", "Zackary",
    "Zane", "Zared", "Zeb", "Zebadiah", "Zebulon", "Zed", "Zeke", "Zeph", "Zephyr", "Zeus", "Zollie", "Zolly"
]


from flask import Flask, request, jsonify, render_template_string

app = Flask(__name__)

@app.errorhandler(404)
def page_not_found(error):
    error_message = """
    <html>
        <head>
            <title>Page Not Found</title>
            <style>
                body {
                    font-family: Arial, sans-serif;
                    background-color: #f4f4f9;
                    color: #333;
                    margin: 0;
                    padding: 0;
                    justify-content: center;
                    align-items: center;
                    height: 100vh;
                    display: flex;
                }
                .container {
                    text-align: center;
                    background-color: #ffffff;
                    border-radius: 10px;
                    padding: 30px;
                    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
                    max-width: 600px;
                    width: 100%;
                }
                h2 {
                    font-size: 2.5em;
                    color: #e74c3c;
                    margin-bottom: 20px;
                }
                h1 {
                    font-size: 10em;
                    color: #e74c3c;
                    margin-bottom: 20px;
                    text-align: center;
                    margin-top: -100px;
                }
                p {
                    font-size: 1.2em;
                    line-height: 1.6;
                    margin: 10px 0;
                    color: #555;
                }
                a {
                    text-decoration: none;
                    color: #3498db;
                    font-weight: bold;
                    transition: color 0.3s;
                }
                a:hover {
                    color: #e74c3c;
                }
                .button {
                    display: inline-block;
                    padding: 10px 20px;
                    font-size: 1.2em;
                    background-color: #3498db;
                    color: white;
                    text-align: center;
                    border-radius: 5px;
                    margin-top: 20px;
                    text-decoration: none;
                    transition: background-color 0.3s;
                }
                .button:hover {
                    background-color: #2980b9;
                }

                .center {
                    display: flex;
                    justify-content: center;
                    align-items: center;
                }
            </style>
        </head>
        <body>
        <div>
        <h1>404</h1>
        <div class="center">
            <div class="container">
                <h2>Oops! An unexpected error occurred.</h2>
                <p>The page you are looking for was not loaded correctly. It might have been deleted, removed, or the link could be broken.</p>
                <p>We suggest you go back to the home page</p>
                <p>If the problem persists, please contact technical support.</p>
            </div>
        </div>
        </div>
        </body>
    </html>
    """
    print(error_message, 404)

    return error_message, 404

@app.route("/404/local")
def local_page_not_found():
    error_message = """
    <html>
    <head>
        <title>Page Not Found</title>
        <style>
            body {
                font-family: Arial, sans-serif;
                background-color: #f4f4f9;
                color: #333;
                margin: 0;
                padding: 0;
                justify-content: center;
                align-items: center;
                height: 100vh;
                display: flex;
            }
            .container {
                text-align: center;
                background-color: #ffffff;
                border-radius: 10px;
                padding: 30px;
                box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
                max-width: 600px;
                width: 100%;
            }
            h2 {
                font-size: 2.5em;
                color: #e74c3c;
                margin-bottom: 20px;
            }
            h1 {
                font-size: 10em;
                color: #e74c3c;
                margin-bottom: 20px;
                text-align: center;
                margin-top: -100px;
            }
            p {
                font-size: 1.2em;
                line-height: 1.6;
                margin: 10px 0;
                color: #555;
            }
            a {
                text-decoration: none;
                color: #3498db;
                font-weight: bold;
                transition: color 0.3s;
            }
            a:hover {
                color: #e74c3c;
            }
            .button {
                display: inline-block;
                padding: 10px 20px;
                font-size: 1.2em;
                background-color: #3498db;
                color: white;
                text-align: center;
                border-radius: 5px;
                margin-top: 20px;
                text-decoration: none;
                transition: background-color 0.3s;
            }
            .button:hover {
                background-color: #2980b9;
            }

            .center {
                display: flex;
                justify-content: center;
                align-items: center;
            }
        </style>
    </head>
   <body>
<div>
<h1>404</h1>
<div class="center">
<div class="container">
<h2>Oops! An unexpected error occurred.</h2>
<p>The "local" page has been removed due to a technical issue that we are trying to resolve as soon as possible.</p>
<p>We apologize for the inconvenience and thank you for your understanding.</p>
<p>Please return to the home page in the meantime.</p>
<p>If the problem persists, please feel free to contact technical support.</p>
</div>
</div>
</div>
</body>
</html>

    """
    print(error_message, 404)
    return error_message, 404

@app.route("/")
def home():
    errors = {
        404: [
            "local"
        ]
    }

    error_list = []

    for error in errors:
        error_list.append(error)
        for page in errors[error]:
            error = str(error)
            page = str(page)
            
            __format = f"<a href='/{error}/{page}/'>{page} - page</a>" 
            error_list.append(__format)

    error_message = """
    """

    for error in error_list:
        error = str(error)
        error_message = str(error_message)

        error_message = error_message + "<br>" + error

    print(error_message)
    return error_message

print("for more information about the error go to this page:")
app.run(debug=True)